
# Type: value


example value

URI: [meta:value](https://w3id.org/biolink/biolinkml/meta/value)


## Domain and Range

[Example](Example.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Example](Example.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:example |

